Python LALR
===========

|build-status| |coverage|

A pure python LALR parser generator

Glossary
--------
Kernel
Kernel core
Production
Symbol


.. |build-status| image:: https://travis-ci.org/bwhmather/python-lalr.png?branch=develop
    :target: https://travis-ci.org/bwhmather/python-lalr
    :alt: Build Status
.. |coverage| image:: https://coveralls.io/repos/bwhmather/python-lalr/badge.png?branch=develop
    :target: https://coveralls.io/r/bwhmather/python-lalr?branch=develop
    :alt: Coverage
.. _LICENSE: ./LICENSE
